@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.32 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.33 {
 
   use 5.014;
   use Moose;
@@ -31,7 +31,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.32 {
 
   my %plugin_versions = qw(
     Alien                0.023
-    Author::Plicease.*   2.32
+    Author::Plicease.*   2.33
     OurPkgVersion        0.12
     MinimumPerl          1.006
     InstallGuide         1.200006
@@ -276,57 +276,6 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.32 {
       ]);
     }
     
-    if(-e ".travis.yml")
-    {
-      my $travis = YAML::LoadFile(".travis.yml");
-      
-      if(exists $travis->{perl} && grep /^5\.(8|10|12)$/, @{ $travis->{perl} })
-      {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "travis is testing prior to 5.14";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-      }
-
-      unless(exists $travis->{perl} && grep /^5\.28$/, @{ $travis->{perl} })
-      {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "travis is not testing Perl 5.28";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-      }
-      
-      unless(exists $travis->{sudo})
-      {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "You have not specified a value for sudo in travis (suggest setting to false for faster travis build)";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-      }
-      
-      if(! defined $travis->{env})
-      {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "Travis no env field";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-      }
-      elsif(ref($travis->{env}) ne 'HASH')
-      {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "Travis env field is not a hash reference";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-      }
-      elsif(grep !/PERL_USE_UNSAFE_INC/, @{ $travis->{env}->{global} })
-      {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "Travis env.global does not have reference to PERL_USE_UNSAFE_INC";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-      }
-    }
-    
     foreach my $test (map { path($_) } bsd_glob ('t/*.t'))
     {
       my @lines = grep !/-no_srand => 1/, grep /use Test2::V0/, $test->lines_utf8;
@@ -382,7 +331,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.32
+version 2.33
 
 =head1 SYNOPSIS
 
